@@ -1,5 +1,5 @@
 name = "csinscapp"
-version = "0.0.8"
+version = "0.0.8.1"
 
 # tested on remi version = "2020.3.10"
 import remi.gui as gui
@@ -370,13 +370,15 @@ class CSinSCApp:
   commands = []
   styles = {}
 
+  title = "CSinSchools Application"
+
   def __init__(self, title = "CSinSchools Application", width = "100%", height = "100%"):
     if title is None:
       raise Exception("Please supply a title for the application.")
     self.events = []  
     self.initialised = False
 
-    self.title = title
+    CSinSCApp.title = title
 
     self.container = gui.Container(width = width, height = height)   
     self.container.style["display"] = "flex;"
@@ -401,7 +403,7 @@ class CSinSCApp:
     control.widget.onmousemove.do(self.on_mouse_move, control)
 
   def remi_thread(self):
-    start(CSinSCApp.MyApp, title = self.title, debug=False, address='0.0.0.0', port=0, multiple_instance = True, userdata = (self,))    
+    start(CSinSCApp.MyApp, title = CSinSCApp.title, debug=False, address='0.0.0.0', port=0, multiple_instance = True, userdata = (self,))    
 
   def main(self):
     self.initialised = True
